======================================
Functions for parsing the result files
======================================

.. automodule:: abed.results.cache
    :members:
    :undoc-members:
    :show-inheritance:
